@@ -19,13 +19,37 @@
 ###########################################################################
 
 import os
+import sys
+import gtk
 
 SF_NAME = 'SeriesFinale'
 SF_COMPACT_NAME = 'seriesfinale'
-SF_VERSION = '0.2.1'
+SF_VERSION = '0.3.6'
 SF_DESCRIPTION = 'SeriesFinale is a TV series browser and tracker application'
 SF_URL = 'http://www.igalia.com'
 
-SF_CONF_FILE = os.getenv('HOME') + '/.osso/%s/%s' % (SF_COMPACT_NAME, 'series.db')
+HOME_PATH = os.getenv('HOME')
+SF_CONF_FOLDER = HOME_PATH + '/.osso/%s' % SF_COMPACT_NAME
+SF_CONF_FILE = SF_CONF_FOLDER + '/%s.conf' % SF_COMPACT_NAME
+SF_DB_FILE = SF_CONF_FOLDER + '/%s' % 'series.db'
+
+DEFAULT_SYSTEM_APP_DIR = os.path.join(sys.prefix,
+                                      'share',
+                                      SF_COMPACT_NAME)
+APP_DIR = DEFAULT_SYSTEM_APP_DIR
+
+if not os.path.exists(APP_DIR):
+    APP_DIR = os.path.dirname(os.path.dirname(__file__))
+    APP_DIR = os.path.join(APP_DIR, 'data')
+
+LOCALE_DIR = os.path.join(APP_DIR, 'locale')
+
+
+DEFAULT_LANGUAGES = os.environ.get('LANGUAGE', '').split(':')
+DEFAULT_LANGUAGES += ['en_US', 'pt_PT']
 
 TVDB_API_KEY = 'FAD75AF31E1B1577'
+
+SECONDARY_TEXT_COLOR = 'SecondaryTextColor'
+ACTIVE_TEXT_COLOR = 'ActiveTextColor'
+DEFAULT_TEXT_COLOR = 'DefaultTextColor'
